==> tmaid-2.4.0.tar.gz: tmaid-2.4.0/src/valchr.h <==
/*
    Text maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __VALCHR_H__
#define __VALCHR_H__


#include "tmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:コード文字入力ダイアログ関数群                                           *
*                                                                             *
******************************************************************************/
/*  ja:コード文字入力ダイアログ表示
    valchr,入力文字
       RET,TRUE:OK,FALSE:Cancel                                             */
gboolean
valchr_dialog (gchar *valchr);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __VALCHR_H__ */

==> tmaid-2.4.2.tar.gz: tmaid-2.4.2/src/valchr.h <==
/*
    Text maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __VALCHR_H__
#define __VALCHR_H__


#include "tmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:コード文字入力ダイアログ関数群                                           *
*                                                                             *
******************************************************************************/
/*  ja:コード文字入力ダイアログ表示
    valchr,入力文字
       RET,TRUE:OK,FALSE:Cancel                                             */
gboolean
valchr_dialog (gunichar *valchr);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __VALCHR_H__ */
